==> naev-0.12.2.tar.gz: naev-0.12.2/dat/naevpedia/lore/factions/soromid.md <==
---
title: "Soromid"
---
<%
wgtfct = require("naevpedia.lore.faction").init( "Soromid" )
%>
<widget wgtfct />

# Soromid

The Soromid are an important faction, and although they are not a Great House of [the Empire](lore/factions/empire), they are very close in practice.

## Organization

* **Leader:** Tribal Representatives
* **Leading Structure:** Tribal Council
* **Government:** Neotribal Communitariasm
* **Formation:** [UST 387](lore/history)
* **Homeworld:** Kataka (Feye system)

## History

### Sorom

Sorom was a fairly hospitable planet, like many others in the galaxy during the Second Growth.
It was settled roughly halfway through [the Growth](lore/history), changed ownership several times during the Faction Wars and eventually came under the rule of the old Empire afterwards.
In this it was about as average as worlds got, just one more property in the vast expanse of the Empire.

But Sorom was also different.
The population suffered from far more frequent and more severe outbreaks of disease than was the norm in [Empire](lore/factions/empire) space.
Though medical science had already progressed to quite a respectable level in those times, the hospitals found themselves challenged more and more by ailments that proved difficult to cure.
Indeed, the pathogens were found to evolve rapidly to grow resistant to all common forms of antibiotics as well as other forms of treatment.

In the end, the microbes won.
The people of Sorom fell victim to a plague unprecedented in human history, one that spanned the entire world.
The plague was airborne, infecting all who breathed the air of Sorom, sparing none.
All attempts at treatment proved futile.
The human immune system, too, lacked the capacity to combat the disease.

[The Empire](lore/factions/empire) was quick to realize the threat Sorom now presented to the galaxy.
With no known cure or inoculation, the plague would lay waste to any world unfortunate enough to be infected by it.
It was therefore decided that Sorom should be quarantined from the rest of humanity.
[The Empire](lore/factions/empire) implemented a blockade to deny any ships landing or takeoff, and destroyed all spaceports on the face of the planet from orbit.
The people of Sorom were left to die.

### Gene Treatment

The people of Sorom had been abandoned.
The plague claimed more and more lives every day.
It would be a matter of years, maybe months before nobody was left alive.
Faced with no hope of survival, the remaining hospitals and research centers decided to gamble everything on a bold plan.
If the human immune system couldn't combat the disease, then it was deficient.
It was to be replaced by something better, something that could purify the system of the pathogen.
It was time to redesign the human body.

As the researchers had precious little time, they found themselves forced to abandon ethics and cut corners.
Many terminally ill patients were experimented upon and died.
Even so, nobody objected.
After all, if this project bore no fruit, all would perish.
And so work desperately continued, claiming life after life until at last a breakthrough was achieved: a new technique for genetic manipulation.

The human genetic code could now be rewritten at will.
More importantly, new DNA could be introduced to give the subject new physical characteristics.
The immune system could be augmented and fortified to combat the disease, and if new strands were to appear the population could easily be gene-treated to become immune to that as well.
For the first time since the Imperial blockade began, the people of Sorom had hope again.

However, it soon became apparent that the genetic rewrite of the human body was an extremely dangerous procedure.
Eight in ten subjects would develop severe rejection symptoms, resulting in death.
Nevertheless, the remaining subjects would recover fully and be totally immune to the plague.
Realizing that a small chance of survival was better than no chance of survival at all, the people of Sorom underwent the treatment.
Many lives were lost, few were saved.
But it was enough.

### The Soromid

The population of Sorom was drastically diminished, but those who survived found themselves more able than before.
With the new gene treatment it had become possible to surpass the limits of the human body, including fertility.
In only a couple of centuries the people of Sorom had replenished their numbers, and their offspring all shared their compatibility with the gene treatment.
They altered their appearances and improved on nearly every part of the human design.
The people felt that they had now become something more than mere human, so they styled themselves the Soromid, after the world that had nearly destroyed them, and begin their new life as new humans.

Soon, the Soromid decided that it was time to return to the stars.
The Imperial blockade had left the system many decades past, so nothing was to stop them.
But rather than rebuild to ancient specifications, the Soromid chose to start from scratch.
They used their understanding of genetics to grow semi-organic ships, thereby improving over known ship designs.
Then they ventured out into the galaxy.

For years Sorom had been in the books as a hazard world that could support no human life, so the appearance of the Soromid came as a shock to the rest of inhabited space.
[The Empire](lore/factions/empire) briefly tried to suppress the Soromid by force on the basis that the plague could still be a threat to other worlds, but when it became apparent that the Soromid carried no infectious diseases whatsoever the Emperor begrudgingly acknowledged their presence in the galaxy.
It also helped that the Soromid ships proved to be quite combat capable.

The Soromid were met with distrust.
Their physical appearance and their uncanny tendency to outperform normal people did not ingratiate them with humanity.
[The Za'lek](lore/factions/zalek) in particular weren't amused with the newcomers, as they couldn't stomach that someone other than them had developed new technology, and technology [the Za'lek](lore/factions/zalek) could not reproduce at that.

Unfazed by the reception of the other factions, the Soromid went to work.
The galaxy had plenty of suitable worlds left to colonize - at least, worlds suitable to the Soromid.
The Soromid had a far greater tolerance for hostile worlds than humans did, and where they did not they could adjust themselves appropriately.
In time, the Soromid claimed many worlds nobody else had ever given a second glance.

And then came the Incident.
For all their improvements and upgrades, the Soromid were hit just as hard as anyone else.
Sorom was caught in the blast and was rendered sterile.
But elsewhere in the galaxy, the Soromid persisted.
All Soromid knew the history of Sorom, and they would not suffer to be destroyed, no matter what the universe threw at them.

Today, the Soromid have laid claim to a considerable part of the northern galaxy.
They have solidly established themselves in the galactic economy, exporting their gene treatment as a service to humanity.
Though deep treatment still results in the death of most who attempt it, small cosmetic alterations have been found to be relatively safe.
It is not at all uncommon for the more fashionable citizen to be genetically augmented.
However, the Soromid have the monopoly on anything beyond that.

## Political Structure

Instead of having a fixed political structure, the Soromid have a very loose and organic political structure that revolves around the idea of tribes.
Generally, each tribe has a council that oversees the day to day management, where all individuals delegate most responsibility.
The members of the council are not necessarily fixed, and fluidly change over time.
Periodically, and when needed, the tribe will gather in councils to decide positions on particular issues or proposals, where efforts are made to reach a consensus.
The same structure of councils happens at a larger scale, where instead of all individuals, tribal representatives get together to reach consensus over matters that affect the Soromid as a whole.

Although it would seem that the overhead of such a system would make it unmanageable at a large scale, due to historic issues and through strong education, young Soromid new humans are raised with a strong focus on putting the community over the individual.
Such a social education, combined with strong customs, helps keep most friction at a minimum, allowing fast and effective decision making.
When frictions arise, each tribe tends to have mechanisms for dealing with this, while for inter-tribal issues, duels or competitions are often used to solve issues and foster camaraderie.

The tribes can consist of a single world or even various star systems.
Each tribe usually consists of largely similarly modified individuals that are genetically compatible, however, some tribes can consist of various dominant genotypes.
As with most of the Soromid structure, it is very flexible and fluid where exceptions are the norm.

==> naev-0.12.6.tar.gz: naev-0.12.6/dat/naevpedia/lore/factions/soromid.md <==
---
title: "Soromid"
---
<%
wgtfct = require("naevpedia.lore.faction").init( "Soromid" )
%>
<widget wgtfct />

# Soromid

The Soromid are an important faction, and although they are not a Great House of [the Empire](lore/factions/empire), they are very close in practice.

## Organization

* **Leader:** Tribal Representatives
* **Leading Structure:** Tribal Council
* **Government:** Neotribal Communitariasm
* **Formation:** [UST 387](lore/history)
* **Homeworld:** Kataka (Feye system)

## History

### Sorom

Sorom was a fairly hospitable planet, like many others in the galaxy during the Second Growth.
It was settled roughly halfway through [the Growth](lore/history), changed ownership several times during the Faction Wars and eventually came under the rule of the old Empire afterwards.
In this it was about as average as worlds got, just one more property in the vast expanse of the Empire.

But Sorom was also different.
The population suffered from far more frequent and more severe outbreaks of disease than was the norm in [Empire](lore/factions/empire) space.
Though medical science had already progressed to quite a respectable level in those times, the hospitals found themselves challenged more and more by ailments that proved difficult to cure.
Indeed, the pathogens were found to evolve rapidly to grow resistant to all common forms of antibiotics as well as other forms of treatment.

In the end, the microbes won.
The people of Sorom fell victim to a plague unprecedented in human history, one that spanned the entire world.
The plague was airborne, infecting all who breathed the air of Sorom, sparing none.
All attempts at treatment proved futile.
The human immune system, too, lacked the capacity to combat the disease.

[The Empire](lore/factions/empire) was quick to realize the threat Sorom now presented to the galaxy.
With no known cure or inoculation, the plague would lay waste to any world unfortunate enough to be infected by it.
It was therefore decided that Sorom should be quarantined from the rest of humanity.
[The Empire](lore/factions/empire) implemented a blockade to deny any ships landing or takeoff, and destroyed all spaceports on the face of the planet from orbit.
The people of Sorom were left to die.

### Gene Treatment

The people of Sorom had been abandoned.
The plague claimed more and more lives every day.
It would be a matter of years, maybe months before nobody was left alive.
Faced with no hope of survival, the remaining hospitals and research centers decided to gamble everything on a bold plan.
If the human immune system couldn't combat the disease, then it was deficient.
It was to be replaced by something better, something that could purify the system of the pathogen.
It was time to redesign the human body.

As the researchers had precious little time, they found themselves forced to abandon ethics and cut corners.
Many terminally ill patients were experimented upon and died.
Even so, nobody objected.
After all, if this project bore no fruit, all would perish.
And so work desperately continued, claiming life after life until at last a breakthrough was achieved: a new technique for genetic manipulation.

The human genetic code could now be rewritten at will.
More importantly, new DNA could be introduced to give the subject new physical characteristics.
The immune system could be augmented and fortified to combat the disease, and if new strands were to appear the population could easily be gene-treated to become immune to that as well.
For the first time since the Imperial blockade began, the people of Sorom had hope again.

However, it soon became apparent that the genetic rewrite of the human body was an extremely dangerous procedure.
Eight in ten subjects would develop severe rejection symptoms, resulting in death.
Nevertheless, the remaining subjects would recover fully and be totally immune to the plague.
Realizing that a small chance of survival was better than no chance of survival at all, the people of Sorom underwent the treatment.
Many lives were lost, few were saved.
But it was enough.

### The Soromid

The population of Sorom was drastically diminished, but those who survived found themselves more able than before.
With the new gene treatment it had become possible to surpass the limits of the human body, including fertility.
In only a couple of centuries the people of Sorom had replenished their numbers, and their offspring all shared their compatibility with the gene treatment.
They altered their appearances and improved on nearly every part of the human design.
The people felt that they had now become something more than mere human, so they styled themselves the Soromid, after the world that had nearly destroyed them, and begin their new life as new humans.

Soon, the Soromid decided that it was time to return to the stars.
The Imperial blockade had left the system many decades past, so nothing was to stop them.
But rather than rebuild to ancient specifications, the Soromid chose to start from scratch.
They used their understanding of genetics to grow semi-organic ships, thereby improving over known ship designs.
Then they ventured out into the galaxy.

For years Sorom had been in the books as a hazard world that could support no human life, so the appearance of the Soromid came as a shock to the rest of inhabited space.
[The Empire](lore/factions/empire) briefly tried to suppress the Soromid by force on the basis that the plague could still be a threat to other worlds, but when it became apparent that the Soromid carried no infectious diseases whatsoever the Emperor begrudgingly acknowledged their presence in the galaxy.
It also helped that the Soromid ships proved to be quite combat capable.

The Soromid were met with distrust.
Their physical appearance and their uncanny tendency to outperform normal people did not ingratiate them with humanity.
[The Za'lek](lore/factions/zalek) in particular weren't amused with the newcomers, as they couldn't stomach that someone other than them had developed new technology, and technology [the Za'lek](lore/factions/zalek) could not reproduce at that.

Unfazed by the reception of the other factions, the Soromid went to work.
The galaxy had plenty of suitable worlds left to colonize - at least, worlds suitable to the Soromid.
The Soromid had a far greater tolerance for hostile worlds than humans did, and where they did not they could adjust themselves appropriately.
In time, the Soromid claimed many worlds nobody else had ever given a second glance.

And then came the Incident.
For all their improvements and upgrades, the Soromid were hit just as hard as anyone else.
Sorom was caught in the blast and was rendered sterile.
But elsewhere in the galaxy, the Soromid persisted.
All Soromid knew the history of Sorom, and they would not suffer to be destroyed, no matter what the universe threw at them.

Today, the Soromid have laid claim to a considerable part of the northern galaxy.
They have solidly established themselves in the galactic economy, exporting their gene treatment as a service to humanity.
Though deep treatment still results in the death of most who attempt it, small cosmetic alterations have been found to be relatively safe.
It is not at all uncommon for the more fashionable citizen to be genetically augmented.
However, the Soromid have the monopoly on anything beyond that.

## Political Structure

Instead of having a fixed political structure, the Soromid have a very loose and organic political structure that revolves around the idea of tribes.
Generally, each tribe has a council that oversees the day to day management, where all individuals delegate most responsibility.
The members of the council are not necessarily fixed, and fluidly change over time.
Periodically, and when needed, the tribe will gather in councils to decide positions on particular issues or proposals, where efforts are made to reach a consensus.
The same structure of councils happens at a larger scale, where instead of all individuals, tribal representatives get together to reach consensus over matters that affect the Soromid as a whole.

Although it would seem that the overhead of such a system would make it unmanageable at a large scale, due to historic issues and through strong education, young Soromid new humans are raised with a strong focus on putting the community over the individual.
Such a social education, combined with strong customs, helps keep most friction at a minimum, allowing fast and effective decision-making.
When frictions arise, each tribe tends to have mechanisms for dealing with this, while for intertribal issues, duels or competitions are often used to solve issues and foster camaraderie.

The tribes can consist of a single world or even various star systems.
Each tribe usually consists of largely similarly modified individuals that are genetically compatible, however, some tribes can consist of various dominant genotypes.
As with most of the Soromid structure, it is very flexible and fluid where exceptions are the norm.
